@@ -714,7 +714,7 @@ secret_collection_async_initable_init_finish (GAsyncInitable *initable,
 	g_return_val_if_fail (g_simple_async_result_is_valid (result, G_OBJECT (initable),
 	                      secret_collection_async_initable_init_async), FALSE);
 
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
+	if (_secret_util_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
 		return FALSE;
 
 	self->pv->constructing = FALSE;
@@ -865,7 +865,7 @@ secret_collection_load_items_finish (SecretCollection *self,
 	g_return_val_if_fail (g_simple_async_result_is_valid (result, G_OBJECT (self),
 	                      secret_collection_load_items), FALSE);
 
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
+	if (_secret_util_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
 		return FALSE;
 
 	return TRUE;
@@ -1042,8 +1042,8 @@ on_create_service (GObject *source,
 	g_object_unref (async);
 }
 
-static GHashTable *
-collection_properties_new (const gchar *label)
+GHashTable *
+_secret_collection_properties_new (const gchar *label)
 {
 	GHashTable *properties;
 	GVariant *value;
@@ -1104,7 +1104,7 @@ secret_collection_create (SecretService *service,
 	                                 secret_collection_create);
 	closure = g_slice_new0 (CreateClosure);
 	closure->cancellable = cancellable ? g_object_ref (cancellable) : NULL;
-	closure->properties = collection_properties_new (label);
+	closure->properties = _secret_collection_properties_new (label);
 	closure->alias = g_strdup (alias);
 	closure->flags = flags;
 	g_simple_async_result_set_op_res_gpointer (res, closure, create_closure_free);
@@ -1146,7 +1146,7 @@ secret_collection_create_finish (GAsyncResult *result,
 
 	res = G_SIMPLE_ASYNC_RESULT (result);
 
-	if (g_simple_async_result_propagate_error (res, error))
+	if (_secret_util_propagate_error (res, error))
 		return NULL;
 
 	closure = g_simple_async_result_get_op_res_gpointer (res);
@@ -1208,7 +1208,7 @@ secret_collection_create_sync (SecretService *service,
 		g_object_ref (service);
 	}
 
-	properties = collection_properties_new (label);
+	properties = _secret_collection_properties_new (label);
 
 	path = secret_service_create_collection_dbus_path_sync (service, properties, alias,
 	                                                        flags, cancellable, error);
@@ -1487,7 +1487,7 @@ secret_collection_search_finish (SecretCollection *self,
 	                      secret_collection_search), NULL);
 
 	async = G_SIMPLE_ASYNC_RESULT (result);
-	if (g_simple_async_result_propagate_error (async, error))
+	if (_secret_util_propagate_error (async, error))
 		return NULL;
 
 	search = g_simple_async_result_get_op_res_gpointer (async);
@@ -1681,7 +1681,7 @@ secret_collection_delete_finish (SecretCollection *self,
 	g_return_val_if_fail (g_simple_async_result_is_valid (result, G_OBJECT (self),
 	                      secret_collection_delete), FALSE);
 
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
+	if (_secret_util_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
 		return FALSE;
 
 	return TRUE;
@@ -2178,7 +2178,7 @@ secret_collection_for_alias_finish (GAsyncResult *result,
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	async = G_SIMPLE_ASYNC_RESULT (result);
-	if (g_simple_async_result_propagate_error (async, error))
+	if (_secret_util_propagate_error (async, error))
 		return NULL;
 	read = g_simple_async_result_get_op_res_gpointer (async);
 	if (read->collection)
