@@ -38,12 +38,12 @@
  * Normally a single #SecretService object can be shared between multiple
  * callers. The secret_service_get() method is used to access this #SecretService
  * object. If a new independent #SecretService object is required, use
- * secret_service_new().
+ * secret_service_open().
  *
  * In order to securely transfer secrets to the Sercret Service, an session
  * is established. This session can be established while initializing a
  * #SecretService object by passing the %SECRET_SERVICE_OPEN_SESSION flag
- * to the secret_service_get() or secret_service_new() functions. In order to
+ * to the secret_service_get() or secret_service_open() functions. In order to
  * establish a session on an already existing #SecretService, use the
  * secret_service_ensure_session() function.
  *
@@ -53,7 +53,7 @@
  * secret items. In order to instantiate #SecretCollection objects which
  * represent those collections while initializing a #SecretService then pass
  * the %SECRET_SERVICE_LOAD_COLLECTIONS flag to the secret_service_get() or
- * secret_service_new() functions. In order to establish a session on an already
+ * secret_service_open() functions. In order to establish a session on an already
  * existing #SecretService, use the secret_service_load_collections() function.
  * To access the list of collections use secret_service_get_collections().
  *
@@ -101,7 +101,7 @@
  *                                   #SecretService
  *
  * Flags which determine which parts of the #SecretService proxy are initialized
- * during a secret_service_get() or secret_service_new() operation.
+ * during a secret_service_get() or secret_service_open() operation.
  */
 
 EGG_SECURE_DEFINE_GLIB_GLOBALS ();
@@ -312,7 +312,7 @@ on_real_prompt_completed (GObject *source,
 	GError *error = NULL;
 	GVariant *retval;
 
-	retval = secret_prompt_perform_finish (SECRET_PROMPT (source), result, NULL, &error);
+	retval = secret_prompt_perform_finish (SECRET_PROMPT (source), result, &error);
 	if (retval != NULL)
 		g_simple_async_result_set_op_res_gpointer (res, retval, (GDestroyNotify)g_variant_unref);
 	if (error != NULL)
@@ -324,6 +324,7 @@ on_real_prompt_completed (GObject *source,
 static void
 secret_service_real_prompt_async (SecretService *self,
                                   SecretPrompt *prompt,
+                                  const GVariantType *return_type,
                                   GCancellable *cancellable,
                                   GAsyncReadyCallback callback,
                                   gpointer user_data)
@@ -333,7 +334,7 @@ secret_service_real_prompt_async (SecretService *self,
 	res =  g_simple_async_result_new (G_OBJECT (self), callback, user_data,
 	                                  secret_service_real_prompt_async);
 
-	secret_prompt_perform (prompt, 0, cancellable,
+	secret_prompt_perform (prompt, 0, return_type, cancellable,
 	                       on_real_prompt_completed,
 	                       g_object_ref (res));
 
@@ -343,12 +344,10 @@ secret_service_real_prompt_async (SecretService *self,
 static GVariant *
 secret_service_real_prompt_finish (SecretService *self,
                                    GAsyncResult *result,
-                                   const GVariantType *return_type,
                                    GError **error)
 {
 	GSimpleAsyncResult *res;
 	GVariant *retval;
-	gchar *string;
 
 	g_return_val_if_fail (g_simple_async_result_is_valid (result, G_OBJECT (self),
 	                      secret_service_real_prompt_async), NULL);
@@ -361,14 +360,6 @@ secret_service_real_prompt_finish (SecretService *self,
 	if (retval == NULL)
 		return NULL;
 
-	if (return_type != NULL && !g_variant_is_of_type (retval, return_type)) {
-		string = g_variant_type_dup_string (return_type);
-		g_warning ("received unexpected result type %s from prompt's Completed signal instead of expected %s",
-		           g_variant_get_type_string (retval), string);
-		g_free (string);
-		return NULL;
-	}
-
 	return g_variant_ref (retval);
 }
 
@@ -496,6 +487,24 @@ secret_service_signal (GDBusProxy *proxy,
 	g_variant_unref (paths);
 }
 
+static GType
+secret_service_real_get_collection_gtype (SecretService *self)
+{
+	SecretServiceClass *klass;
+
+	klass = SECRET_SERVICE_GET_CLASS (self);
+	return klass->collection_gtype;
+}
+
+static GType
+secret_service_real_get_item_gtype (SecretService *self)
+{
+	SecretServiceClass *klass;
+
+	klass = SECRET_SERVICE_GET_CLASS (self);
+	return klass->item_gtype;
+}
+
 static void
 secret_service_class_init (SecretServiceClass *klass)
 {
@@ -516,6 +525,8 @@ secret_service_class_init (SecretServiceClass *klass)
 
 	klass->item_gtype = SECRET_TYPE_ITEM;
 	klass->collection_gtype = SECRET_TYPE_COLLECTION;
+	klass->get_item_gtype = secret_service_real_get_item_gtype;
+	klass->get_collection_gtype = secret_service_real_get_collection_gtype;
 
 	/**
 	 * SecretService:flags:
@@ -537,7 +548,7 @@ secret_service_class_init (SecretServiceClass *klass)
 	 *
 	 * To load the collections, specify the %SECRET_SERVICE_LOAD_COLLECTIONS
 	 * initialization flag when calling the secret_service_get() or
-	 * secret_service_new() functions. Or call the secret_service_load_collections()
+	 * secret_service_open() functions. Or call the secret_service_load_collections()
 	 * method.
 	 */
 	g_object_class_install_property (object_class, PROP_COLLECTIONS,
@@ -914,7 +925,7 @@ secret_service_disconnect (void)
 }
 
 /**
- * secret_service_new:
+ * secret_service_open:
  * @service_gtype: the GType of the new secret service
  * @service_bus_name: (allow-none): the D-Bus service name of the secret service
  * @flags: flags for which service functionality to ensure is initialized
@@ -937,12 +948,12 @@ secret_service_disconnect (void)
  * This method will return immediately and complete asynchronously.
  */
 void
-secret_service_new (GType service_gtype,
-                    const gchar *service_bus_name,
-                    SecretServiceFlags flags,
-                    GCancellable *cancellable,
-                    GAsyncReadyCallback callback,
-                    gpointer user_data)
+secret_service_open (GType service_gtype,
+                     const gchar *service_bus_name,
+                     SecretServiceFlags flags,
+                     GCancellable *cancellable,
+                     GAsyncReadyCallback callback,
+                     gpointer user_data)
 {
 	g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
 	g_return_if_fail (g_type_is_a (service_gtype, SECRET_TYPE_SERVICE));
@@ -963,7 +974,7 @@ secret_service_new (GType service_gtype,
 }
 
 /**
- * secret_service_new_finish:
+ * secret_service_open_finish:
  * @result: the asynchronous result passed to the callback
  * @error: location to place an error on failure
  *
@@ -974,8 +985,8 @@ secret_service_new (GType service_gtype,
  *          should be released with g_object_unref().
  */
 SecretService *
-secret_service_new_finish (GAsyncResult *result,
-                           GError **error)
+secret_service_open_finish (GAsyncResult *result,
+                            GError **error)
 {
 	GObject *source_object;
 	GObject *object;
@@ -995,7 +1006,7 @@ secret_service_new_finish (GAsyncResult *result,
 }
 
 /**
- * secret_service_new_sync:
+ * secret_service_open_sync:
  * @service_gtype: the GType of the new secret service
  * @service_bus_name: (allow-none): the D-Bus service name of the secret service
  * @flags: flags for which service functionality to ensure is initialized
@@ -1021,11 +1032,11 @@ secret_service_new_finish (GAsyncResult *result,
  *          should be released with g_object_unref().
  */
 SecretService *
-secret_service_new_sync (GType service_gtype,
-                         const gchar *service_bus_name,
-                         SecretServiceFlags flags,
-                         GCancellable *cancellable,
-                         GError **error)
+secret_service_open_sync (GType service_gtype,
+                          const gchar *service_bus_name,
+                          SecretServiceFlags flags,
+                          GCancellable *cancellable,
+                          GError **error)
 {
 	g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), NULL);
 	g_return_val_if_fail (g_type_is_a (service_gtype, SECRET_TYPE_SERVICE), NULL);
@@ -1664,6 +1675,7 @@ secret_service_prompt_sync (SecretService *self,
  * secret_service_prompt:
  * @self: the secret service
  * @prompt: the prompt
+ * @return_type: (allow-none): the variant type of the prompt result
  * @cancellable: optional cancellation object
  * @callback: called when the operation completes
  * @user_data: data to be passed to the callback
@@ -1680,6 +1692,7 @@ secret_service_prompt_sync (SecretService *self,
 void
 secret_service_prompt (SecretService *self,
                        SecretPrompt *prompt,
+                       const GVariantType *return_type,
                        GCancellable *cancellable,
                        GAsyncReadyCallback callback,
                        gpointer user_data)
@@ -1693,14 +1706,13 @@ secret_service_prompt (SecretService *self,
 	klass = SECRET_SERVICE_GET_CLASS (self);
 	g_return_if_fail (klass->prompt_async != NULL);
 
-	(klass->prompt_async) (self, prompt, cancellable, callback, user_data);
+	(klass->prompt_async) (self, prompt, return_type, cancellable, callback, user_data);
 }
 
 /**
  * secret_service_prompt_finish:
  * @self: the secret service
  * @result: the asynchronous result passed to the callback
- * @return_type: the variant type of the prompt result
  * @error: location to place an error on failure
  *
  * Complete asynchronous operation to perform prompting for a #SecretPrompt.
@@ -1715,7 +1727,6 @@ secret_service_prompt (SecretService *self,
 GVariant *
 secret_service_prompt_finish (SecretService *self,
                               GAsyncResult *result,
-                              const GVariantType *return_type,
                               GError **error)
 {
 	SecretServiceClass *klass;
@@ -1727,5 +1738,61 @@ secret_service_prompt_finish (SecretService *self,
 	klass = SECRET_SERVICE_GET_CLASS (self);
 	g_return_val_if_fail (klass->prompt_finish != NULL, NULL);
 
-	return (klass->prompt_finish) (self, result, return_type, error);
+	return (klass->prompt_finish) (self, result, error);
+}
+
+/**
+ * secret_service_get_collection_gtype:
+ * @self: the secret service
+ *
+ * Get the GObject type for collections instantiated by this service.
+ * This will always be either #SecretCollection or derived from it.
+ *
+ * Returns: the gobject type for collections
+ */
+GType
+secret_service_get_collection_gtype (SecretService *self)
+{
+	SecretServiceClass *klass;
+	GType type;
+
+	g_return_val_if_fail (SECRET_IS_SERVICE (self), 0);
+
+	klass = SECRET_SERVICE_GET_CLASS (self);
+	g_return_val_if_fail (klass->get_collection_gtype != NULL,
+	                      SECRET_TYPE_COLLECTION);
+
+	type = (klass->get_collection_gtype) (self);
+	g_return_val_if_fail (g_type_is_a (type, SECRET_TYPE_COLLECTION),
+	                      SECRET_TYPE_COLLECTION);
+
+	return type;
+}
+
+/**
+ * secret_service_get_item_gtype:
+ * @self: the collection
+ *
+ * Get the GObject type for items instantiated by this collection.
+ * This will always be either #SecretItem or derived from it.
+ *
+ * Returns: the gobject type for items
+ */
+GType
+secret_service_get_item_gtype (SecretService *self)
+{
+	SecretServiceClass *klass;
+	GType type;
+
+	g_return_val_if_fail (SECRET_IS_SERVICE (self), 0);
+
+	klass = SECRET_SERVICE_GET_CLASS (self);
+	g_return_val_if_fail (klass->get_item_gtype != NULL,
+	                      SECRET_TYPE_ITEM);
+
+	type = (klass->get_item_gtype) (self);
+	g_return_val_if_fail (g_type_is_a (type, SECRET_TYPE_ITEM),
+	                      SECRET_TYPE_ITEM);
+
+	return type;
 }
