@@ -16,6 +16,7 @@
 #include "config.h"
 
 #include "secret-attributes.h"
+#include "secret-private.h"
 
 #include "egg/egg-testing.h"
 
@@ -123,6 +124,59 @@ test_build_bad_type (void)
 	g_test_trap_assert_stderr ("*invalid type*");
 }
 
+static void
+test_validate_schema (void)
+{
+	GHashTable *attributes;
+	gboolean ret;
+
+	attributes = g_hash_table_new (g_str_hash, g_str_equal);
+	g_hash_table_replace (attributes, "number", "1");
+	g_hash_table_replace (attributes, "string", "test");
+	g_hash_table_replace (attributes, "xdg:schema", "org.mock.Schema");
+
+	ret = _secret_attributes_validate (&MOCK_SCHEMA, attributes, G_STRFUNC, TRUE);
+	g_assert (ret == TRUE);
+
+	g_hash_table_unref (attributes);
+}
+
+static void
+test_validate_schema_bad (void)
+{
+	GHashTable *attributes;
+	gboolean ret;
+
+	attributes = g_hash_table_new (g_str_hash, g_str_equal);
+	g_hash_table_replace (attributes, "number", "1");
+	g_hash_table_replace (attributes, "string", "test");
+	g_hash_table_replace (attributes, "xdg:schema", "mismatched.Schema");
+
+	if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDERR)) {
+		ret = _secret_attributes_validate (&MOCK_SCHEMA, attributes, G_STRFUNC, TRUE);
+		g_assert (ret == FALSE);
+	}
+
+	g_hash_table_unref (attributes);
+}
+
+static void
+test_validate_libgnomekeyring (void)
+{
+	GHashTable *attributes;
+	gboolean ret;
+
+	attributes = g_hash_table_new (g_str_hash, g_str_equal);
+	g_hash_table_replace (attributes, "number", "1");
+	g_hash_table_replace (attributes, "string", "test");
+	g_hash_table_replace (attributes, "gkr:compat", "blah-dee-blah");
+
+	ret = _secret_attributes_validate (&MOCK_SCHEMA, attributes, G_STRFUNC, TRUE);
+	g_assert (ret == TRUE);
+
+	g_hash_table_unref (attributes);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -138,5 +192,9 @@ main (int argc, char **argv)
 	g_test_add_func ("/attributes/build-non-utf8-string", test_build_non_utf8_string);
 	g_test_add_func ("/attributes/build-bad-type", test_build_bad_type);
 
+	g_test_add_func ("/attributes/validate-schema", test_validate_schema);
+	g_test_add_func ("/attributes/validate-schema-bad", test_validate_schema_bad);
+	g_test_add_func ("/attributes/validate-libgnomekeyring", test_validate_libgnomekeyring);
+
 	return g_test_run ();
 }
