@@ -45,6 +45,7 @@ setup (Test *test,
 
 	test->service = secret_service_get_sync (SECRET_SERVICE_NONE, NULL, &error);
 	g_assert_no_error (error);
+	g_object_add_weak_pointer (G_OBJECT (test->service), (gpointer *)&test->service);
 }
 
 static void
@@ -53,7 +54,7 @@ teardown (Test *test,
 {
 	g_object_unref (test->service);
 	secret_service_disconnect ();
-	egg_assert_not_object (test->service);
+	g_assert (test->service == NULL);
 
 	mock_service_stop ();
 }
@@ -97,12 +98,13 @@ test_perform_sync (Test *test,
 	g_assert_no_error (error);
 	g_assert (retval != NULL);
 	g_variant_unref (retval);
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
 	g_assert_cmpuint (value, ==, 0);
 	g_source_remove (increment_id);
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -124,6 +126,7 @@ test_perform_run (Test *test,
 	g_assert_no_error (error);
 	g_assert (retval != NULL);
 	g_variant_unref (retval);
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
 	g_assert_cmpuint (value, >, 0);
 	g_source_remove (increment_id);
@@ -132,7 +135,7 @@ test_perform_run (Test *test,
 	egg_test_wait_idle ();
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -145,13 +148,14 @@ test_perform_async (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/simple");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
-	secret_prompt_perform (prompt, 0, NULL, on_async_result, &result);
+	secret_prompt_perform (prompt, 0, NULL, NULL, on_async_result, &result);
 	g_assert (result == NULL);
 
 	egg_test_wait ();
 
-	retval = secret_prompt_perform_finish (prompt, result, NULL, &error);
+	retval = secret_prompt_perform_finish (prompt, result, &error);
 	g_assert_no_error (error);
 	g_assert (retval != NULL);
 	g_variant_unref (retval);
@@ -161,7 +165,7 @@ test_perform_async (Test *test,
 	egg_test_wait_idle ();
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -175,9 +179,10 @@ test_perform_cancel (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/delay");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
 	cancellable = g_cancellable_new ();
-	secret_prompt_perform (prompt, 0, cancellable, on_async_result, &result);
+	secret_prompt_perform (prompt, 0, NULL, cancellable, on_async_result, &result);
 	g_assert (result == NULL);
 
 	g_cancellable_cancel (cancellable);
@@ -185,7 +190,7 @@ test_perform_cancel (Test *test,
 
 	egg_test_wait ();
 
-	retval = secret_prompt_perform_finish (prompt, result, NULL, &error);
+	retval = secret_prompt_perform_finish (prompt, result, &error);
 	g_assert_no_error (error);
 	g_assert (retval != NULL);
 	g_variant_unref (retval);
@@ -196,7 +201,7 @@ test_perform_cancel (Test *test,
 	/* Due to GDBus threading races */
 	egg_test_wait_until (100);
 
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -208,13 +213,14 @@ test_perform_fail (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/error");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
 	retval = secret_prompt_perform_sync (prompt, 0, NULL, NULL, &error);
 	g_assert_error (error, G_DBUS_ERROR, G_DBUS_ERROR_NOT_SUPPORTED);
 	g_assert (retval == NULL);
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -226,13 +232,14 @@ test_perform_vanish (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/vanish");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
 	retval = secret_prompt_perform_sync (prompt, 0, NULL, NULL, &error);
 	g_assert_no_error (error);
 	g_assert (retval == NULL);
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -244,6 +251,7 @@ test_prompt_result (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/result");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
 	retval = secret_prompt_perform_sync (prompt, 0, NULL, G_VARIANT_TYPE_STRING, &error);
 	g_assert_no_error (error);
@@ -252,7 +260,7 @@ test_prompt_result (Test *test,
 	g_variant_unref (retval);
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -264,6 +272,7 @@ test_prompt_window_id (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/window");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
 	retval = secret_prompt_perform_sync (prompt, 555, NULL, G_VARIANT_TYPE_STRING, &error);
 	g_assert_no_error (error);
@@ -272,7 +281,7 @@ test_prompt_window_id (Test *test,
 	g_variant_unref (retval);
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -284,6 +293,7 @@ test_service_sync (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/simple");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
 	retval = secret_service_prompt_sync (test->service, prompt, NULL, NULL, &error);
 	g_assert_no_error (error);
@@ -291,7 +301,7 @@ test_service_sync (Test *test,
 	g_variant_unref (retval);
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -304,13 +314,14 @@ test_service_async (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/simple");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
-	secret_service_prompt (test->service, prompt, NULL, on_async_result, &result);
+	secret_service_prompt (test->service, prompt, NULL, NULL, on_async_result, &result);
 	g_assert (result == NULL);
 
 	egg_test_wait ();
 
-	retval = secret_service_prompt_finish (test->service, result, NULL, &error);
+	retval = secret_service_prompt_finish (test->service, result, &error);
 	g_assert_no_error (error);
 	g_assert (retval != NULL);
 	g_variant_unref (retval);
@@ -320,7 +331,7 @@ test_service_async (Test *test,
 	egg_test_wait_idle ();
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -333,13 +344,14 @@ test_service_fail (Test *test,
 	GVariant *retval;
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/error");
+	g_object_add_weak_pointer (G_OBJECT (prompt), (gpointer *)&prompt);
 
-	secret_service_prompt (test->service, prompt, NULL, on_async_result, &result);
+	secret_service_prompt (test->service, prompt, NULL, NULL, on_async_result, &result);
 	g_assert (result == NULL);
 
 	egg_test_wait ();
 
-	retval = secret_service_prompt_finish (test->service, result, NULL, &error);
+	retval = secret_service_prompt_finish (test->service, result, &error);
 	g_assert_error (error, G_DBUS_ERROR, G_DBUS_ERROR_NOT_SUPPORTED);
 	g_assert (retval == NULL);
 	g_object_unref (result);
@@ -348,7 +360,7 @@ test_service_fail (Test *test,
 	egg_test_wait_idle ();
 
 	g_object_unref (prompt);
-	egg_assert_not_object (prompt);
+	g_assert (prompt == NULL);
 }
 
 static void
@@ -362,13 +374,13 @@ test_service_path (Test *test,
 
 	prompt = _secret_prompt_instance (test->service, "/org/freedesktop/secrets/prompts/simple");
 
-	secret_service_prompt (test->service, prompt, NULL, on_async_result, &result);
+	secret_service_prompt (test->service, prompt, NULL, NULL, on_async_result, &result);
 	g_assert (result == NULL);
 
 	g_object_unref (prompt);
 	egg_test_wait ();
 
-	retval = secret_service_prompt_finish (test->service, result, NULL, &error);
+	retval = secret_service_prompt_finish (test->service, result, &error);
 	g_assert_no_error (error);
 	g_assert (retval != NULL);
 	g_variant_unref (retval);
